==> edge-login-ui-rn-3.1.2.tgz: package/lib/components/scenes/newAccount/NewAccountTosScene.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Linking, ScrollView } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { getAppConfig } from '../../../common/appConfig';
import { lstrings } from '../../../common/locales/strings';
import { useCreateAccountHandler } from '../../../hooks/useCreateAccount';
import { useHandler } from '../../../hooks/useHandler';
import { useImports } from '../../../hooks/useImports';
import { useScrollToEnd } from '../../../hooks/useScrollToEnd';
import { useDispatch } from '../../../types/ReduxTypes';
import { EdgeAnim } from '../../common/EdgeAnim';
import { showChallengeModal, showError } from '../../services/AirshipInstance';
import { useTheme } from '../../services/ThemeContext';
import { Checkbox } from '../../themed/Checkbox';
import { EdgeText } from '../../themed/EdgeText';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const TosComponent = (props) => {
    const { branding, hidePasswordTerms, onBack, onNext } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const [termValues, setTermValues] = React.useState(hidePasswordTerms ? [false, false, false] : [false, false, false, false]);
    const showNext = !termValues.includes(false);
    const scrollViewRef = useScrollToEnd(showNext);
    const buttonType = theme.preferPrimaryButton ? 'primary' : 'secondary';
    const { appName = lstrings.app_name_default } = branding;
    const terms = [
        sprintf(lstrings.terms_one, appName),
        hidePasswordTerms ? lstrings.terms_two_alt : lstrings.terms_two,
        ...(hidePasswordTerms ? [] : [sprintf(lstrings.terms_three, appName)]),
        sprintf(lstrings.terms_four, appName)
    ];
    const handleStatusChange = useHandler((index, value) => {
        const newTermValues = [...termValues];
        newTermValues[index] = value;
        setTermValues(newTermValues);
    });
    return (React.createElement(ThemedScene, { onBack: onBack, title: lstrings.account_confirmation },
        React.createElement(ScrollView, { ref: scrollViewRef, contentContainerStyle: styles.content },
            React.createElement(EdgeAnim, { enter: { type: 'fadeInRight', distance: 50 } },
                React.createElement(EdgeText, { style: styles.subtitle }, `${lstrings.review}: ${lstrings.read_understod_2}`)),
            terms.map((term, index) => (React.createElement(EdgeAnim, { key: index, enter: { type: 'fadeInRight', distance: 50 * (index + 2) } },
                React.createElement(Checkbox, { textStyle: styles.term, value: termValues[index], onChange: (value) => handleStatusChange(index, value), marginRem: [0, 0, 1.33, 0] }, term)))),
            React.createElement(EdgeAnim, { enter: { type: 'fadeInDown' } },
                React.createElement(EdgeText, { style: styles.agreeText, numberOfLines: 2, onPress: () => __awaiter(void 0, void 0, void 0, function* () { return yield Linking.openURL(getAppConfig().termsOfServiceSite); }) },
                    lstrings.read_understod_1,
                    React.createElement(EdgeText, { style: styles.agreeTextLink }, lstrings.read_understod_2))),
            React.createElement(EdgeAnim, { enter: { type: 'fadeInDown' }, exit: { type: 'fadeOutDown' }, style: styles.actions, visible: showNext },
                React.createElement(MainButton, { label: lstrings.confirm, paddingRem: 0.7, type: buttonType, onPress: onNext })))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(0.5)
    },
    subtitle: {
        fontFamily: theme.fontFaceBold,
        color: theme.secondaryText,
        fontSize: theme.rem(1),
        marginBottom: theme.rem(1.5)
    },
    term: {
        fontSize: theme.rem(0.875)
    },
    agreeText: {
        width: '60%',
        alignSelf: 'center',
        marginTop: theme.rem(1),
        marginHorizontal: theme.rem(2),
        fontSize: theme.rem(0.875)
    },
    agreeTextLink: {
        fontSize: theme.rem(0.875),
        color: theme.linkText
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(2.75),
        minHeight: theme.rem(6)
    }
}));
export const NewAccountTosScene = (props) => {
    const { route, branding } = props;
    const { password, pin, username } = route.params;
    const dispatch = useDispatch();
    const handleBack = useHandler(() => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'newAccountPin', params: Object.assign({}, route.params) }
        });
    });
    const { experimentConfig, onLogEvent = () => { } } = useImports();
    const handleCreateAccount = useCreateAccountHandler();
    const handleNext = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (experimentConfig.signupCaptcha === 'withCaptcha') {
            onLogEvent('Signup_Captcha_Shown');
            const result = yield showChallengeModal();
            // User closed the modal
            if (result == null) {
                onLogEvent('Signup_Captcha_Quit');
                return;
            }
            if (!result) {
                onLogEvent('Signup_Captcha_Failed');
                showError(lstrings.failed_captcha_error);
                return;
            }
            onLogEvent('Signup_Captcha_Passed');
        }
        let errorText;
        try {
            dispatch({
                type: 'NAVIGATE',
                data: {
                    name: 'newAccountWait',
                    params: {
                        title: lstrings.great_job,
                        message: lstrings.hang_tight + '\n' + lstrings.secure_account
                    }
                }
            });
            const account = yield handleCreateAccount({ username, password, pin });
            dispatch({
                type: 'NAVIGATE',
                data: {
                    name: 'newAccountReview',
                    params: Object.assign(Object.assign({}, route.params), { account })
                }
            });
        }
        catch (error) {
            showError(error);
            errorText = String(error);
            dispatch({
                type: 'NAVIGATE',
                data: {
                    name: 'newAccountTos',
                    params: route.params
                }
            });
        }
        onLogEvent('Signup_Terms_Agree_and_Create_User', {
            error: errorText
        });
    }));
    return (React.createElement(TosComponent, { hidePasswordTerms: route.params.username == null, branding: branding, onBack: handleBack, onNext: handleNext }));
};
export const UpgradeTosScene = (props) => {
    const { route, branding } = props;
    const { account, password, username } = route.params;
    const { onLogEvent = () => { } } = useImports();
    const dispatch = useDispatch();
    const handleBack = useHandler(() => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'upgradeUsername', params: Object.assign({}, route.params) }
        });
    });
    const handleNext = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        let errorText;
        try {
            yield account.changeUsername({
                username,
                password
            });
            const pin = yield account.getPin();
            dispatch({
                type: 'NAVIGATE',
                data: {
                    name: 'upgradeAccountReview',
                    params: Object.assign(Object.assign({}, route.params), { pin })
                }
            });
        }
        catch (error) {
            showError(error);
            errorText = String(error);
        }
        onLogEvent('Backup_Terms_Agree_and_Create_User', { error: errorText });
    }));
    return (React.createElement(TosComponent, { branding: branding, hidePasswordTerms: false, onBack: handleBack, onNext: handleNext }));
};

==> edge-login-ui-rn-3.2.0.tgz: package/lib/components/scenes/newAccount/NewAccountTosScene.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Linking, ScrollView } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { getAppConfig } from '../../../common/appConfig';
import { lstrings } from '../../../common/locales/strings';
import { useCreateAccountHandler } from '../../../hooks/useCreateAccount';
import { useHandler } from '../../../hooks/useHandler';
import { useImports } from '../../../hooks/useImports';
import { useScrollToEnd } from '../../../hooks/useScrollToEnd';
import { useDispatch } from '../../../types/ReduxTypes';
import { EdgeAnim } from '../../common/EdgeAnim';
import { showChallengeModal, showError } from '../../services/AirshipInstance';
import { useTheme } from '../../services/ThemeContext';
import { Checkbox } from '../../themed/Checkbox';
import { EdgeText } from '../../themed/EdgeText';
import { ThemedScene } from '../../themed/ThemedScene';
import { ButtonsViewUi4 } from '../../ui4/ButtonsViewUi4';
const TosComponent = (props) => {
    const { branding, hidePasswordTerms, onBack, onNext } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const [termValues, setTermValues] = React.useState(hidePasswordTerms ? [false, false, false] : [false, false, false, false]);
    const showNext = !termValues.includes(false);
    const scrollViewRef = useScrollToEnd(showNext);
    const { appName = lstrings.app_name_default } = branding;
    const terms = [
        sprintf(lstrings.terms_one, appName),
        hidePasswordTerms ? lstrings.terms_two_alt : lstrings.terms_two,
        ...(hidePasswordTerms ? [] : [sprintf(lstrings.terms_three, appName)]),
        sprintf(lstrings.terms_four, appName)
    ];
    const handleStatusChange = useHandler((index, value) => {
        const newTermValues = [...termValues];
        newTermValues[index] = value;
        setTermValues(newTermValues);
    });
    return (React.createElement(ThemedScene, { onBack: onBack, title: lstrings.account_confirmation },
        React.createElement(ScrollView, { ref: scrollViewRef, contentContainerStyle: styles.content },
            React.createElement(EdgeAnim, { enter: { type: 'fadeInRight', distance: 50 } },
                React.createElement(EdgeText, { style: styles.subtitle }, `${lstrings.review}: ${lstrings.read_understod_2}`)),
            terms.map((term, index) => (React.createElement(EdgeAnim, { key: index, enter: { type: 'fadeInRight', distance: 50 * (index + 2) } },
                React.createElement(Checkbox, { textStyle: styles.term, value: termValues[index], onChange: (value) => handleStatusChange(index, value), marginRem: [0, 0, 1.33, 0] }, term)))),
            React.createElement(EdgeAnim, { enter: { type: 'fadeInDown' } },
                React.createElement(EdgeText, { style: styles.agreeText, numberOfLines: 2, onPress: () => __awaiter(void 0, void 0, void 0, function* () { return yield Linking.openURL(getAppConfig().termsOfServiceSite); }) },
                    lstrings.read_understod_1,
                    React.createElement(EdgeText, { style: styles.agreeTextLink }, lstrings.read_understod_2))),
            React.createElement(EdgeAnim, { enter: { type: 'fadeInDown' }, exit: { type: 'fadeOutDown' }, style: styles.actions, visible: showNext },
                React.createElement(ButtonsViewUi4, { primary: {
                        label: lstrings.confirm,
                        onPress: onNext
                    }, parentType: "scene" })))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(0.5)
    },
    subtitle: {
        fontFamily: theme.fontFaceBold,
        color: theme.secondaryText,
        fontSize: theme.rem(1),
        marginBottom: theme.rem(1.5)
    },
    term: {
        fontSize: theme.rem(0.875)
    },
    agreeText: {
        width: '60%',
        alignSelf: 'center',
        marginTop: theme.rem(1),
        marginHorizontal: theme.rem(2),
        fontSize: theme.rem(0.875)
    },
    agreeTextLink: {
        fontSize: theme.rem(0.875),
        color: theme.linkText
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(2.75),
        minHeight: theme.rem(6)
    }
}));
export const NewAccountTosScene = (props) => {
    const { route, branding } = props;
    const { password, pin, username } = route.params;
    const dispatch = useDispatch();
    const handleBack = useHandler(() => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'newAccountPin', params: Object.assign({}, route.params) }
        });
    });
    const { experimentConfig, onLogEvent = () => { } } = useImports();
    const handleCreateAccount = useCreateAccountHandler();
    const handleNext = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (experimentConfig.signupCaptcha === 'withCaptcha') {
            onLogEvent('Signup_Captcha_Shown');
            const result = yield showChallengeModal();
            // User closed the modal
            if (result == null) {
                onLogEvent('Signup_Captcha_Quit');
                return;
            }
            if (!result) {
                onLogEvent('Signup_Captcha_Failed');
                showError(lstrings.failed_captcha_error);
                return;
            }
            onLogEvent('Signup_Captcha_Passed');
        }
        let errorText;
        try {
            dispatch({
                type: 'NAVIGATE',
                data: {
                    name: 'newAccountWait',
                    params: {
                        title: lstrings.great_job,
                        message: lstrings.hang_tight + '\n' + lstrings.secure_account
                    }
                }
            });
            const account = yield handleCreateAccount({ username, password, pin });
            dispatch({
                type: 'NAVIGATE',
                data: {
                    name: 'newAccountReview',
                    params: Object.assign(Object.assign({}, route.params), { account })
                }
            });
        }
        catch (error) {
            showError(error);
            errorText = String(error);
            dispatch({
                type: 'NAVIGATE',
                data: {
                    name: 'newAccountTos',
                    params: route.params
                }
            });
        }
        onLogEvent('Signup_Terms_Agree_and_Create_User', {
            error: errorText
        });
    }));
    return (React.createElement(TosComponent, { hidePasswordTerms: route.params.username == null, branding: branding, onBack: handleBack, onNext: handleNext }));
};
export const UpgradeTosScene = (props) => {
    const { route, branding } = props;
    const { account, password, username } = route.params;
    const { onLogEvent = () => { } } = useImports();
    const dispatch = useDispatch();
    const handleBack = useHandler(() => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'upgradeUsername', params: Object.assign({}, route.params) }
        });
    });
    const handleNext = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        let errorText;
        try {
            yield account.changeUsername({
                username,
                password
            });
            const pin = yield account.getPin();
            dispatch({
                type: 'NAVIGATE',
                data: {
                    name: 'upgradeAccountReview',
                    params: Object.assign(Object.assign({}, route.params), { pin })
                }
            });
        }
        catch (error) {
            showError(error);
            errorText = String(error);
        }
        onLogEvent('Backup_Terms_Agree_and_Create_User', { error: errorText });
    }));
    return (React.createElement(TosComponent, { branding: branding, hidePasswordTerms: false, onBack: handleBack, onNext: handleNext }));
};
